@@ -15,12 +15,12 @@
 // Dependencies
 #include "../detail/setup.hpp"
 
-#ifndef GLM_ENABLE_EXPERIMENTAL
-#	error "GLM: GLM_GTX_range is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
-#endif
-
-#if !GLM_HAS_RANGE_FOR
-#	error "GLM_GTX_range requires C++11 suppport or 'range for'"
+#if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
+#	ifndef GLM_ENABLE_EXPERIMENTAL
+#		pragma message("GLM: GLM_GTX_range is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
+#	elif
+#		pragma message("GLM: GLM_GTX_range extension included")
+#	endif
 #endif
 
 #include "../gtc/type_ptr.hpp"
