@@ -24,18 +24,18 @@
 #include <string>
 #include <cmath>
 
-#ifndef GLM_ENABLE_EXPERIMENTAL
-#	error "GLM: GLM_GTX_string_cast is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
+#if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
+#	ifndef GLM_ENABLE_EXPERIMENTAL
+#		pragma message("GLM: GLM_GTX_string_cast is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
+#	elif
+#		pragma message("GLM: GLM_GTX_string_cast extension included")
+#	endif
 #endif
 
 #if(GLM_COMPILER & GLM_COMPILER_CUDA)
 #	error "GLM_GTX_string_cast is not supported on CUDA compiler"
 #endif
 
-#if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
-#	pragma message("GLM: GLM_GTX_string_cast extension included")
-#endif
-
 namespace glm
 {
 	/// @addtogroup gtx_string_cast
